==> haskell-openssl-streams-1.2.2.0-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openssl-streams
version: 1.2.2.0
id: openssl-streams-1.2.2.0-LorYW3sWeDgDgihSalGxSb
key: openssl-streams-1.2.2.0-LorYW3sWeDgDgihSalGxSb
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).
category: Network, IO-Streams
abi: d0cc4675f8ac36c6ccbe1f01b193124d
exposed: True
exposed-modules:
    System.IO.Streams.SSL
import-dirs: /usr/lib/ghc-8.6.5/site-local/openssl-streams-1.2.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/openssl-streams-1.2.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/openssl-streams-1.2.2.0
hs-libraries: HSopenssl-streams-1.2.2.0-LorYW3sWeDgDgihSalGxSb
depends:
    HsOpenSSL-0.11.4.17-GG27uOBAaRn9kgjxLUqEdb base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.1.0-Cd8ZPT412kJAmvyGDhCrWM
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
haddock-interfaces: /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock
haddock-html: /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openssl-streams-1.2.2.0-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openssl-streams
version: 1.2.2.0
id: openssl-streams-1.2.2.0-2zqb5LJySAl9zJFjaDnJVg
key: openssl-streams-1.2.2.0-2zqb5LJySAl9zJFjaDnJVg
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).
category: Network, IO-Streams
abi: b8f4fc4a5fce4f7fb33428126a2e75b8
exposed: True
exposed-modules:
    System.IO.Streams.SSL
import-dirs: /usr/lib/ghc-8.6.5/site-local/openssl-streams-1.2.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/openssl-streams-1.2.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/openssl-streams-1.2.2.0
hs-libraries: HSopenssl-streams-1.2.2.0-2zqb5LJySAl9zJFjaDnJVg
depends:
    HsOpenSSL-0.11.4.17-JrhPbxwKwdLHiDowLLDHMF base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.1.0-6b6obZLMkBRHsFePmr5BtR
    network-2.8.0.0-LvSlvEKiGr81Yl4BCXERfa
haddock-interfaces: /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock
haddock-html: /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
